@@ -63,7 +63,7 @@ class LSV2:
             logging.info(
                 "safe mode is active, login and system commands are restricted"
             )
-            self._known_logins = (Login.INSPECT, Login.FILETRANSFER)
+            self._known_logins = (Login.INSPECT, Login.FILETRANSFER, Login.MONITOR)
             self._known_sys_cmd = (
                 ParCCC.SET_BUF1024,
                 ParCCC.SET_BUF512,
@@ -1359,11 +1359,12 @@ class LSV2:
                 or entry["Name"].endswith(":")
             ):
                 continue
+            current_fs_element = str(current_path + entry["Name"]).replace("/", PATH_SEP)
             if entry["is_directory"] is True and descend is True:
-                if self.change_directory(current_path + entry["Name"]):
+                if self.change_directory(current_fs_element):
                     content.extend(self._walk_dir())
             else:
-                content.append(current_path + entry["Name"])
+                content.append(current_fs_element)
         self.change_directory(current_path)
         return content
 
